==> jc-1.4.0.tar.gz: gnu/xml/dom/ImplementationSource.h <==
// public class gnu.xml.dom.ImplementationSource

// class file dependencies
// @dep_class ad8e4466516c680c gnu_xml_dom_ImplementationSource
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_ImplementationSource_H_
#define _JC_gnu_xml_dom_ImplementationSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_org_w3c_dom_DOMImplementation$object;
struct _jc_org_w3c_dom_DOMImplementationList$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_ImplementationSource$sub_refs	_jc_gnu_xml_dom_ImplementationSource$sub_refs;
typedef struct _jc_gnu_xml_dom_ImplementationSource$sub_nonrefs	_jc_gnu_xml_dom_ImplementationSource$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_ImplementationSource$refs	_jc_gnu_xml_dom_ImplementationSource$refs;
typedef struct _jc_gnu_xml_dom_ImplementationSource$nonrefs	_jc_gnu_xml_dom_ImplementationSource$nonrefs;
typedef struct _jc_gnu_xml_dom_ImplementationSource$object	_jc_gnu_xml_dom_ImplementationSource$object;

typedef struct _jc_gnu_xml_dom_ImplementationSource$fields_struct	_jc_gnu_xml_dom_ImplementationSource$fields_struct;
typedef const struct _jc_gnu_xml_dom_ImplementationSource$vmethods	_jc_gnu_xml_dom_ImplementationSource$vmethods;
typedef const struct _jc_gnu_xml_dom_ImplementationSource$vtable	_jc_gnu_xml_dom_ImplementationSource$vtable;
typedef const struct _jc_gnu_xml_dom_ImplementationSource$vtype	_jc_gnu_xml_dom_ImplementationSource$vtype;

// Class fields structure
struct _jc_gnu_xml_dom_ImplementationSource$fields_struct {
	struct _jc_java_lang_String$object	*DIGITS;
	_jc_object_array	*implementations;
};
extern _jc_gnu_xml_dom_ImplementationSource$fields_struct _jc_gnu_xml_dom_ImplementationSource$class_fields;

// Constructors
extern void _jc_gnu_xml_dom_ImplementationSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_dom_ImplementationSource$method$getDOMImplementation$d6af02b546b219ba(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_gnu_xml_dom_ImplementationSource$method$getDOMImplementationList$53d8a0e2cc1a5bf2(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_ImplementationSource$method$getFeature$0c5d237ed3766298(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *, jint, jint);
extern struct _jc_object *_jc_gnu_xml_dom_ImplementationSource$method$getImplementations$bcd3658be015239f(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_gnu_xml_dom_ImplementationSource$method$parseFeatures$4e0fe355391fcf69(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_ImplementationSource$method_info$getDOMImplementation$d6af02b546b219ba;
extern _jc_method _jc_gnu_xml_dom_ImplementationSource$method_info$getDOMImplementationList$53d8a0e2cc1a5bf2;
extern _jc_method _jc_gnu_xml_dom_ImplementationSource$method_info$getFeature$0c5d237ed3766298;
extern _jc_method _jc_gnu_xml_dom_ImplementationSource$method_info$getImplementations$bcd3658be015239f;
extern _jc_method _jc_gnu_xml_dom_ImplementationSource$method_info$parseFeatures$4e0fe355391fcf69;

// Static methods
extern void _jc_gnu_xml_dom_ImplementationSource$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_dom_ImplementationSource$vmethods {
	struct _jc_object	*(*getDOMImplementation$d6af02b546b219ba)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*getDOMImplementationList$53d8a0e2cc1a5bf2)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*getFeature$0c5d237ed3766298)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *, jint, jint);
	struct _jc_object	*(*getImplementations$bcd3658be015239f)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*parseFeatures$4e0fe355391fcf69)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_xml_dom_ImplementationSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_ImplementationSource$vmethods	gnu_xml_dom_ImplementationSource;
};

// Vtype
struct _jc_gnu_xml_dom_ImplementationSource$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_ImplementationSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_ImplementationSource$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_ImplementationSource$refs {
    _jc_gnu_xml_dom_ImplementationSource$sub_refs	gnu_xml_dom_ImplementationSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_ImplementationSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_ImplementationSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_ImplementationSource$sub_nonrefs	gnu_xml_dom_ImplementationSource;
};

// Object instance structure
struct _jc_gnu_xml_dom_ImplementationSource$object {
	_jc_gnu_xml_dom_ImplementationSource$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_ImplementationSource$vtype	*vtype;
	_jc_gnu_xml_dom_ImplementationSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_ImplementationSource$vtype _jc_gnu_xml_dom_ImplementationSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_ImplementationSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_ImplementationSource$class_object;

#endif	/* _JC_gnu_xml_dom_ImplementationSource_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/ImplementationSource.h <==
// public class gnu.xml.dom.ImplementationSource

// class file dependencies
// @dep_class ad8e4466516c680c gnu_xml_dom_ImplementationSource
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_ImplementationSource_H_
#define _JC_gnu_xml_dom_ImplementationSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_org_w3c_dom_DOMImplementation$object;
struct _jc_org_w3c_dom_DOMImplementationList$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_ImplementationSource$sub_refs	_jc_gnu_xml_dom_ImplementationSource$sub_refs;
typedef struct _jc_gnu_xml_dom_ImplementationSource$sub_nonrefs	_jc_gnu_xml_dom_ImplementationSource$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_ImplementationSource$refs	_jc_gnu_xml_dom_ImplementationSource$refs;
typedef struct _jc_gnu_xml_dom_ImplementationSource$nonrefs	_jc_gnu_xml_dom_ImplementationSource$nonrefs;
typedef struct _jc_gnu_xml_dom_ImplementationSource$object	_jc_gnu_xml_dom_ImplementationSource$object;

typedef struct _jc_gnu_xml_dom_ImplementationSource$fields_struct	_jc_gnu_xml_dom_ImplementationSource$fields_struct;
typedef const struct _jc_gnu_xml_dom_ImplementationSource$vmethods	_jc_gnu_xml_dom_ImplementationSource$vmethods;
typedef const struct _jc_gnu_xml_dom_ImplementationSource$vtable	_jc_gnu_xml_dom_ImplementationSource$vtable;
typedef const struct _jc_gnu_xml_dom_ImplementationSource$vtype	_jc_gnu_xml_dom_ImplementationSource$vtype;

// Class fields structure
struct _jc_gnu_xml_dom_ImplementationSource$fields_struct {
	struct _jc_java_lang_String$object	*DIGITS;
	_jc_object_array	*implementations;
};
extern _jc_gnu_xml_dom_ImplementationSource$fields_struct _jc_gnu_xml_dom_ImplementationSource$class_fields;

// Constructors
extern void _jc_gnu_xml_dom_ImplementationSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_dom_ImplementationSource$method$getDOMImplementation$d6af02b546b219ba(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_dom_ImplementationSource$method$getDOMImplementationList$53d8a0e2cc1a5bf2(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_ImplementationSource$method$getFeature$0c5d237ed3766298(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_dom_ImplementationSource$method$getImplementations$bcd3658be015239f(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_dom_ImplementationSource$method$parseFeatures$4e0fe355391fcf69(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_ImplementationSource$method_info$getDOMImplementation$d6af02b546b219ba;
extern _jc_method _jc_gnu_xml_dom_ImplementationSource$method_info$getDOMImplementationList$53d8a0e2cc1a5bf2;
extern _jc_method _jc_gnu_xml_dom_ImplementationSource$method_info$getFeature$0c5d237ed3766298;
extern _jc_method _jc_gnu_xml_dom_ImplementationSource$method_info$getImplementations$bcd3658be015239f;
extern _jc_method _jc_gnu_xml_dom_ImplementationSource$method_info$parseFeatures$4e0fe355391fcf69;

// Static methods
extern void _jc_gnu_xml_dom_ImplementationSource$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_dom_ImplementationSource$vmethods {
	struct _jc_object	*(*getDOMImplementation$d6af02b546b219ba)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getDOMImplementationList$53d8a0e2cc1a5bf2)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getFeature$0c5d237ed3766298)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_object	*(*getImplementations$bcd3658be015239f)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*parseFeatures$4e0fe355391fcf69)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationSource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_ImplementationSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_ImplementationSource$vmethods	gnu_xml_dom_ImplementationSource;
};

// Vtype
struct _jc_gnu_xml_dom_ImplementationSource$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_ImplementationSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_ImplementationSource$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_ImplementationSource$refs {
    _jc_gnu_xml_dom_ImplementationSource$sub_refs	gnu_xml_dom_ImplementationSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_ImplementationSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_ImplementationSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_ImplementationSource$sub_nonrefs	gnu_xml_dom_ImplementationSource;
};

// Object instance structure
struct _jc_gnu_xml_dom_ImplementationSource$object {
	_jc_gnu_xml_dom_ImplementationSource$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_ImplementationSource$vtype	*vtype;
	_jc_gnu_xml_dom_ImplementationSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_ImplementationSource$vtype _jc_gnu_xml_dom_ImplementationSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_ImplementationSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_ImplementationSource$class_object;

#endif	/* _JC_gnu_xml_dom_ImplementationSource_H_ */
